From afdf1aff307f9214e81314ddb0868eb0ef6a874f Mon Sep 17 00:00:00 2001
From: Tom Rondeau <trondeau@vt.edu>
Date: Thu, 7 Mar 2013 10:28:09 -0500
Subject: blocks: removing bin_statistics_f from core; now in gr-blocks.

---
 gr-uhd/examples/python/usrp_spectrum_sense.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

(limited to 'gr-uhd/examples/python/usrp_spectrum_sense.py')

diff --git a/gr-uhd/examples/python/usrp_spectrum_sense.py b/gr-uhd/examples/python/usrp_spectrum_sense.py
index 077365a916..39e85ab18a 100755
--- a/gr-uhd/examples/python/usrp_spectrum_sense.py
+++ b/gr-uhd/examples/python/usrp_spectrum_sense.py
@@ -49,7 +49,7 @@ class tune(gr.feval_dd):
 
     def eval(self, ignore):
         """
         This method is called from gr.bin_statistics_f when it wants
         to change the center frequency.  This method tunes the front
         end to the new center frequency, and returns the new frequency
         as its result.
@@ -183,9 +183,9 @@ class my_top_block(gr.top_block):
 
         self.msgq = gr.msg_queue(16)
         self._tune_callback = tune(self)        # hang on to this to keep it from being GC'd
-        stats = gr.bin_statistics_f(self.fft_size, self.msgq,
-                                    self._tune_callback, tune_delay,
-                                    dwell_delay)
+        stats = blocks.bin_statistics_f(self.fft_size, self.msgq,
+                                        self._tune_callback, tune_delay,
+                                        dwell_delay)
 
         # FIXME leave out the log10 until we speed it up
 	#self.connect(self.u, s2v, ffter, c2mag, log, stats)
@@ -49,7 +49,7 @@ class tune(gr.feval_dd):
     def eval(self, ignore):
         """
-        This method is called from gr.bin_statistics_f when it wants
+        This method is called from blocks.bin_statistics_f when it wants
         to change the center frequency.  This method tunes the front
         end to the new center frequency, and returns the new frequency
-- 
cgit v1.2.3